/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { convertToDataTestId } from '../../support/tech.util';
import { AttachmentContainerE2EComponent } from '../attachment/attachment.e2e.component';
import { UserProfileE2EComponent } from '../user-profile/user-profile.component.e2e';

export class PostfachMailE2EComponent {

	private readonly createMailButtonWithText: string = 'create-mail-button-with-text';
	private readonly createMailButtonWithoutText: string = 'create-mail-button-without-text';
	private readonly list: string = 'postfach-mail-list';
	private readonly noPostfachText: string = 'no-postfach-text';
	private readonly attachments: string = 'postfach-nachricht-attachments-container';
	private readonly downloadButtonWithIcon: string = 'postfach-pdf-export-button';
	private readonly downloadButtonWithLabel: string = 'postfach-pdf-export-label-button';

	private readonly locatorRoot: string = 'postfach-nachrichten-container-in-vorgang';

	public getRoot() {
		return cy.getTestElement(this.locatorRoot);
	}

	public getCreateButtonWithText() {
		return cy.getTestElement(this.createMailButtonWithText);
	}

	public getCreateButtonWithoutText() {
		return cy.getTestElement(this.createMailButtonWithoutText);
	}

	public getList() {
		return cy.getTestElement(this.list);
	}

	public getNoPostfachText() {
		return cy.getTestElement(this.noPostfachText);
	}

	public getListItem(subject: string): PostfachMailListItem {
		return new PostfachMailListItem(subject);
	}

	public getAttachments() {
		return cy.getTestElement(this.attachments);
	}

	public getDownloadButtonWithIcon() {
		return cy.getTestElement(this.downloadButtonWithIcon);
	}

	public getDownloadButtonWithLabel() {
		return cy.getTestElement(this.downloadButtonWithLabel);
	}
}

export class PostfachMailListItem {//TODO: Rename -> PostfachMailListItemE2EComponent

	private readonly locatorCreatedAt: string = 'mail-created-at';
	private readonly locatorSubject: string = 'mail-subject';
	private readonly locatorText: string = 'mail-text';
	private readonly locatorReplyIcon: string = 'reply-icon';
	private readonly locatorSentAt: string = 'mail-sent-at';

	private readonly locatorMailSendErrorText: string = 'mail-send-error-text';
	private readonly locatorMailSendErrorIcon: string = 'mail-send-error-icon';
	private readonly locatorMailResendButton: string = 'mail-resend-button';

	private readonly attachmentContainer: AttachmentContainerE2EComponent = new AttachmentContainerE2EComponent();

	private locatorRoot: string;

	constructor(subject: string) {
		this.locatorRoot = convertToDataTestId(subject) + '-item';
	}

	public getRoot() {
		return cy.getTestElement(this.locatorRoot);
	}

	public getSubject() {
		return this.getRoot().getTestElement(this.locatorSubject);
	}

	public getText() {
		return this.getRoot().getTestElement(this.locatorText);
	}

	public getCreatedAt() {
		return this.getRoot().getTestElement(this.locatorCreatedAt);
	}

	public getUserProfile(): UserProfileE2EComponent {
		return new UserProfileE2EComponent(this.locatorRoot);
	}

	public getReplyIcon() {
		return this.getRoot().getTestElement(this.locatorReplyIcon);
	}

	public getSentAt() {
		return this.getRoot().getTestElement(this.locatorSentAt);
	}

	public getMailSendErrorText() {
		return this.getRoot().getTestElement(this.locatorMailSendErrorText);
	}

	public getMailSendErrorIcon() {
		return this.getRoot().getTestElement(this.locatorMailSendErrorIcon);
	}

	public getResendButton() {
		return this.getRoot().getTestElement(this.locatorMailResendButton);
	}

	public getAttachmentContainer(): AttachmentContainerE2EComponent {
		return this.attachmentContainer;
	}
}