/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { KommentareInVorgangE2EComponent } from '../../../components/kommentar/kommentar-list.e2e.component';
import { UserE2E } from '../../../model/user';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { contains, exist, haveText, notExist } from '../../../support/cypress.util';
import { getUserManagerUserEmil, getUserManagerUserPeter, getUserManagerUserSabine, getUserSabine, initUsermanagerUsers, loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgang } from '../../../support/vorgang-util';

describe('Kommentar', () => {
	const mainPage: MainPage = new MainPage();

	const vorgangPage: VorgangPage = new VorgangPage();
	const kommentarContainer: KommentareInVorgangE2EComponent = vorgangPage.getKommentarContainer();

	const kommentarText: string = 'Test text to test the test text test';

	const vorgang: VorgangE2E = createVorgang();
	const userSabine: UserE2E = getUserSabine();

	before(() => {
		initVorgang(vorgang);
		initUsermanagerUsers([getUserManagerUserSabine(), getUserManagerUserPeter(), getUserManagerUserEmil()]);

		loginAsSabine();

		waitForSpinnerToDisappear();
		exist(mainPage.getVorgangList().getRoot());
	})

	after(() => {
		dropCollections();
	})

	describe('create', () => {

		it('Open Vorgang-Detail-Page', () => {
			mainPage.getVorgangList().getListItem(vorgang.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangPage.getVorgangDetailHeader().getRoot());
		})

		it('should only show hinzufuegen button initial', () => {
			exist(kommentarContainer.getHinzufuegenButton());
			notExist(kommentarContainer.getFormular());
		})

		describe('click on hinzufuegen button', () => {

			it('should show formular', () => {
				kommentarContainer.getHinzufuegenButton().click();
				waitForSpinnerToDisappear();

				exist(kommentarContainer.getFormular());
			})

			it('should hide hinzufuegen button', () => {
				notExist(kommentarContainer.getHinzufuegenButton());
			})

			it('should show formular buttons', () => {
				exist(kommentarContainer.getFormularAbbrechenButton());
				exist(kommentarContainer.getFormularSpeichernButton());
			})
		})

		describe('click on hinzufuegen button in formular', () => {

			it('should show error on invalid input', () => {
				kommentarContainer.getFormularSpeichernButton().click();
				waitForSpinnerToDisappear();

				exist(kommentarContainer.getTextError());
			})

			it('should show only hinzufuegen button on valid input', () => {
				kommentarContainer.getTextInput().clear().type(kommentarText);

				kommentarContainer.getFormularSpeichernButton().click();
				exist(vorgangPage.getSpinner());
				notExist(kommentarContainer.getKommentar(kommentarText).getUserProfile().getIconContainer().getAssignedIcon());
				exist(vorgangPage.getSpinner());
				waitForSpinnerToDisappear();
				exist(kommentarContainer.getKommentar(kommentarText).getUserProfile().getIconContainer().getAssignedIcon());

				notExist(kommentarContainer.getTextError());
				notExist(kommentarContainer.getFormular());
				exist(kommentarContainer.getHinzufuegenButton());
			})

			it('should show entry in list', () => {
				exist(kommentarContainer.getKommentar(kommentarText).getRoot());
			})

			it('should show user profile at kommentar', () => {
				exist(kommentarContainer.getKommentar(kommentarText).getUserProfile().getIconContainer().getAssignedIcon());
				haveText(kommentarContainer.getKommentar(kommentarText).getUserProfile().getIconContainer().getAssignedIcon(), userSabine.initials);
				contains(kommentarContainer.getKommentar(kommentarText).getUserProfile().getName(), userSabine.fullName);
				exist(kommentarContainer.getKommentar(kommentarText).getCreatedAt());
			})
		})

		describe('click on abbrechen button in formular', () => {

			it('shoul hide formular', () => {
				kommentarContainer.getHinzufuegenButton().click();
				kommentarContainer.getFormularAbbrechenButton().click();

				notExist(kommentarContainer.getFormular());
				exist(kommentarContainer.getHinzufuegenButton());
			})
		})
	})

	describe('edit', () => {

		it('should only show hinzufuegen button initial', () => {
			exist(kommentarContainer.getHinzufuegenButton());
			notExist(kommentarContainer.getFormular());
		})

		describe('click on existing kommentar', () => {

			it('should show formular with value', () => {
				exist(kommentarContainer.getHinzufuegenButton());

				kommentarContainer.getKommentar(kommentarText).getRoot().click();

				exist(kommentarContainer.getFormularAbbrechenButton());
				exist(kommentarContainer.getFormularSpeichernButton());
			})

			it('should show formular buttons', () => {
				exist(kommentarContainer.getFormularAbbrechenButton());
				exist(kommentarContainer.getFormularSpeichernButton());
			})
		})

		describe('click on "speichern" button in formular', () => {

			const kommentarText: string = 'Test text to test the test text test';

			it('should show only hinzufuegen button on valid input', () => {
				kommentarContainer.getTextInput().clear().type(kommentarText);

				kommentarContainer.getFormularSpeichernButton().click();

				notExist(kommentarContainer.getTextError());
				notExist(kommentarContainer.getFormular());
				exist(kommentarContainer.getHinzufuegenButton());
			})

			it('should show entry in list', () => {
				exist(kommentarContainer.getKommentar(kommentarText).getRoot());
			})
		})

		describe('click on abbrechen button in formular', () => {

			it('shoul hide formular', () => {
				kommentarContainer.getKommentar(kommentarText).getRoot().click();
				kommentarContainer.getFormularAbbrechenButton().click();

				notExist(kommentarContainer.getFormular());
				exist(kommentarContainer.getHinzufuegenButton());
			})
		})
	})
});
