import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { KommentareInVorgangE2EComponent } from 'apps/alfa-e2e/src/components/kommentar/kommentar-list.e2e.component';
import { PostfachMailE2EComponent } from 'apps/alfa-e2e/src/components/postfach/postfach-mail.e2e.component';
import { UserProfileE2EComponent } from 'apps/alfa-e2e/src/components/user-profile/user-profile.component.e2e';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { WiedervorlageInVorgangE2EComponent } from 'apps/alfa-e2e/src/components/wiedervorlage/wiedervorlage-in-vorgang.e2e.component';
import { initVorgangAttachedItem } from 'apps/alfa-e2e/src/support/vorgang-attached-item-util';
import { createWiedervorlageAttachedItem, createWiedervorlageUriByVorgangIdAndWiedervorlageId } from 'apps/alfa-e2e/src/support/wiedervorlage-util';
import { SnackBarE2EComponent } from '../../../components/ui/snackbar.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { VorgangE2E, VorgangMessagesE2E, VorgangStatusE2E, vorgangStatusLabelE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections, visitUrl } from '../../../support/cypress-helper';
import { contains, exist, haveText, notExist } from '../../../support/cypress.util';
import { loginAsLudwig, loginAsSabine } from '../../../support/user-util';
import { buildVorgang, initVorgaenge, initVorgang, objectIds } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang Löschen anfordern', () => {
	const mainPage: MainPage = new MainPage();
	const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();
	const snackBar: SnackBarE2EComponent = mainPage.getSnackBar();

	const vorgangPage: VorgangPage = new VorgangPage();
	const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

	const vorgangNichtLoeschbar: VorgangE2E = { ...buildVorgang(objectIds[5], 'DoNichtLoeschbar'), status: VorgangStatusE2E.ABGESCHLOSSEN };

	const vorgangAbgeschlossenLoeschenAnfordern: VorgangE2E = { ...buildVorgang(objectIds[0], 'DoAbgeschlossenLoeschenAnfordern'), status: VorgangStatusE2E.ABGESCHLOSSEN };
	const vorgangAbgeschlossenLoeschenAnfordernRevoke: VorgangE2E = { ...buildVorgang(objectIds[1], 'DoAbgeschlossenRevokeLoeschenAnfordern'), status: VorgangStatusE2E.ABGESCHLOSSEN };

	const vorgangVerworfenLoeschenAnfordern: VorgangE2E = { ...buildVorgang(objectIds[2], 'DoVerworfenLoeschenAnfordern'), status: VorgangStatusE2E.VERWORFEN };
	const vorgangVerworfenLoeschenAnfordernRevoke: VorgangE2E = { ...buildVorgang(objectIds[3], 'DoVerworfenRevokeLoeschenAnfordern'), status: VorgangStatusE2E.VERWORFEN };

	const wiedervorlageAttachedItem = createWiedervorlageAttachedItem(objectIds[4], vorgangAbgeschlossenLoeschenAnfordern._id.$oid);
	const wiedervorlageUrl = createWiedervorlageUriByVorgangIdAndWiedervorlageId(objectIds[0], objectIds[4]);


	describe('Nicht löschen (Ludwig kann keinen Vorgang löschen, für den er selbst die Löschanforderung gestellt hat)', () => {
		before(() => {
			initVorgang(vorgangNichtLoeschbar);

			loginAsLudwig();

			waitForSpinnerToDisappear();
			exist(vorgangList.getRoot());
		})

		it('Öffne Vorgang für Löschanforderung', () => {
			vorgangList.getListItem(vorgangNichtLoeschbar.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangPage.getVorgangDetailHeader().getRoot());
		})

		it('Vorgang ist im Status: Abgeschlossen', () => {
			haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E.ABGESCHLOSSEN);
		})

		it('Löschen anfordern klicken', () => {
			vorgangFormularButtons.getLoeschenAnfordernButton().click();
			waitForSpinnerToDisappear();
		})

		it('Vorgang ist im Status: Zu Löschen', () => {
			haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E.ZU_LOESCHEN);
		})

		it('Button zum Endgültig löschen ist nicht vorhanden', () => {
			waitForSpinnerToDisappear();
			notExist(vorgangFormularButtons.getEndgueltigLoeschenButton());
		})
	})

	describe('with user Sabine', () => {
		before(() => {
			initVorgaenge([vorgangAbgeschlossenLoeschenAnfordern, vorgangAbgeschlossenLoeschenAnfordernRevoke, vorgangVerworfenLoeschenAnfordern, vorgangVerworfenLoeschenAnfordernRevoke]);
			initVorgangAttachedItem([wiedervorlageAttachedItem]);

			loginAsSabine();

			waitForSpinnerToDisappear();
			exist(vorgangList.getRoot());
		})

		after(() => {
			dropCollections();
		})

		describe('Abgeschlossen: löschen anfordern', () => {

			it('Open Vorgang-Detail-Page', () => {
				vorgangList.getListItem(vorgangAbgeschlossenLoeschenAnfordern.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangPage.getVorgangDetailHeader().getRoot());
			})

			describe('by button', () => {

				it('should have status Abgeschlossen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangAbgeschlossenLoeschenAnfordern.status]);
				})

				it('should click Löschen anfordern button', () => {
					vorgangFormularButtons.getLoeschenAnfordernButton().click();
					waitForSpinnerToDisappear();
				})

				it('should show snackBar message', () => {
					exist(snackBar.getCloseButton());
					contains(snackBar.getMessage(), VorgangMessagesE2E.LOESCHEN_ANFORDERN)
				})

				it('should close snackBar', () => {
					snackBar.getCloseButton().click();

					notExist(snackBar.getMessage());
				})

				it('should have status zu Löschen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ZU_LOESCHEN]);
				})

				it('should redirect Wiedervorlage link to Vorgang', () => {
					visitUrl(wiedervorlageUrl);

					exist(vorgangPage.getVorgangDetailHeader().getRoot());
				})

				it('should show snackBar message', () => {
					exist(snackBar.getCloseButton());
					contains(snackBar.getMessage(), VorgangMessagesE2E.WIEDERVORLAGE_BEARBEITEN_NICHT_MOEGLICH)
				})

				it('should close snackBar', () => {
					snackBar.getCloseButton().click();

					notExist(snackBar.getMessage());
				})

				it('back to vorgang list', () => {
					vorgangPage.getSubnavigation().getBackButton().click();
					waitForSpinnerToDisappear();

					exist(vorgangList.getRoot());
				})

				it('should have status zu Löschen', () => {
					haveText(vorgangList.getListItem(vorgangAbgeschlossenLoeschenAnfordern.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ZU_LOESCHEN]);
				})
			})
		})

		describe('Disable functions', () => {

			it('Open Vorgang-Detail-Page', () => {
				vorgangList.getListItem(vorgangAbgeschlossenLoeschenAnfordern.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangPage.getVorgangDetailHeader().getRoot());
			})

			it('should not have add comment button', () => {
				const kommentarContainer: KommentareInVorgangE2EComponent = vorgangPage.getKommentarContainer();

				notExist(kommentarContainer.getHinzufuegenButton());
			})

			it('should disable edit comment', () => {
				const kommentarContainer: KommentareInVorgangE2EComponent = vorgangPage.getKommentarContainer();

				notExist(kommentarContainer.getFormular());
			})

			it('should not have create postfach mail buttons', () => {
				const postfachMailContainer: PostfachMailE2EComponent = vorgangPage.getPostfachMailcontainer();

				notExist(postfachMailContainer.getCreateButtonWithoutText());
				notExist(postfachMailContainer.getCreateButtonWithText());
			})

			it('should not have add wiedervorlage button', () => {
				const createWiedervorlageButton = vorgangPage.getWiedervorlagenContainer().getCreateWiedervorlageButton();

				notExist(createWiedervorlageButton);
			})

			it('should disable open Wiedervorlage-Page link ', () => {
				const wiedervorlageInVorgang: WiedervorlageInVorgangE2EComponent = vorgangPage.getWiedervorlagenContainer().getWiedervorlage('Wiedervorlage');

				notExist(wiedervorlageInVorgang.getLink());
			})

			it('should not have user assign button', () => {
				const userProfileContainer: UserProfileE2EComponent = vorgangPage.getVorgangDetailHeader().getUserContainer();

				notExist(userProfileContainer.getRoot());
			})

			it('back to vorgang list', () => {
				vorgangPage.getSubnavigation().getBackButton().click();
				waitForSpinnerToDisappear();

				exist(vorgangList.getRoot());
			})

		})

		describe('Abgeschlossen: löschen anfordern und rückgängig machen', () => {

			it('Open Vorgang-Detail-Page', () => {
				vorgangList.getListItem(vorgangAbgeschlossenLoeschenAnfordernRevoke.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangPage.getVorgangDetailHeader().getRoot());
			})

			describe('by icon-button', () => {

				it('should have status Abgeschlossen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangAbgeschlossenLoeschenAnfordernRevoke.status]);
				})

				it('should show snackBar message', () => {
					vorgangPage.getSubnavigation().getLoeschenAnfordernByIconButton().click();
					waitForSpinnerToDisappear();

					exist(snackBar.getCloseButton());
					contains(snackBar.getMessage(), VorgangMessagesE2E.LOESCHEN_ANFORDERN);
				})

				it('should close snackbar on revoke', () => {
					snackBar.getRevokeButton().click();
					waitForSpinnerToDisappear();

					notExist(snackBar.getMessage());
				})

				it('should show status Abgeschlossen', () => {
					notExist(vorgangPage.getProgressBar());

					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ABGESCHLOSSEN]);
				})

				it('back to vorgang list', () => {
					vorgangPage.getSubnavigation().getBackButton().click();
					waitForSpinnerToDisappear();

					exist(vorgangList.getRoot());
				})

				it('should have status Abgeschlossen', () => {
					haveText(vorgangList.getListItem(vorgangAbgeschlossenLoeschenAnfordernRevoke.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ABGESCHLOSSEN])
				})
			})
		})

		describe('Verworfen: löschen anfordern', () => {

			it('Open Vorgang-Detail-Page', () => {
				vorgangList.getListItem(vorgangVerworfenLoeschenAnfordern.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangPage.getVorgangDetailHeader().getRoot());
			})

			describe('by button', () => {

				it('should have status Verworfen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangVerworfenLoeschenAnfordern.status]);
				})

				it('should show snackBar message', () => {
					vorgangFormularButtons.getLoeschenAnfordernButton().click();
					waitForSpinnerToDisappear();

					exist(snackBar.getCloseButton());
					contains(snackBar.getMessage(), VorgangMessagesE2E.LOESCHEN_ANFORDERN)
				})

				it('should close snackBar', () => {
					snackBar.getCloseButton().click();

					notExist(snackBar.getMessage());
				})

				it('should have status zu Löschen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ZU_LOESCHEN]);
				})

				it('back to vorgang list', () => {
					vorgangPage.getSubnavigation().getBackButton().click();
					waitForSpinnerToDisappear();

					exist(vorgangList.getRoot());
				})

				it('should have status zu Löschen', () => {
					haveText(vorgangList.getListItem(vorgangVerworfenLoeschenAnfordern.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ZU_LOESCHEN]);
				})
			})
		})

		describe('Verworfen: löschen anfordern und rückgängig machen', () => {

			it('Open Vorgang-Detail-Page', () => {
				vorgangList.getListItem(vorgangVerworfenLoeschenAnfordernRevoke.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangPage.getVorgangDetailHeader().getRoot());
			})

			describe('by icon-button', () => {

				it('should have status Verworfen', () => {
					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangVerworfenLoeschenAnfordernRevoke.status]);
				})

				it('should show snackBar message', () => {
					vorgangPage.getSubnavigation().getLoeschenAnfordernByIconButton().click();
					waitForSpinnerToDisappear();

					exist(snackBar.getCloseButton());
					contains(snackBar.getMessage(), VorgangMessagesE2E.LOESCHEN_ANFORDERN);
				})

				it('should close snackbar on revoke', () => {
					snackBar.getRevokeButton().click();
					waitForSpinnerToDisappear();

					notExist(snackBar.getMessage());
				})

				it('should show status Verworfen', () => {
					notExist(vorgangPage.getProgressBar());

					haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.VERWORFEN]);
				})

				it('back to vorgang list', () => {
					vorgangPage.getSubnavigation().getBackButton().click();
					waitForSpinnerToDisappear();

					exist(vorgangList.getRoot());
				})

				it('should have status Verworfen', () => {
					haveText(vorgangList.getListItem(vorgangVerworfenLoeschenAnfordernRevoke.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.VERWORFEN])
				})
			})
		})
	})
});


