/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { SnackBarE2EComponent } from '../../../components/ui/snackbar.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { VorgangE2E, VorgangMessagesE2E, VorgangStatusE2E, vorgangStatusLabelE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { contains, exist, haveText, notExist } from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import { buildVorgang, initVorgaenge, objectIds } from '../../../support/vorgang-util';

describe('Vorgang abschliessen', () => {
	const mainPage: MainPage = new MainPage();
	const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();
	const snackBar: SnackBarE2EComponent = mainPage.getSnackBar();

	const vorgangPage: VorgangPage = new VorgangPage();
	const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

	const vorgangAbschliessen: VorgangE2E = { ...buildVorgang(objectIds[0], 'DoAbschliessen'), status: VorgangStatusE2E.BESCHIEDEN };
	const vorgangAbschliessenRevoke: VorgangE2E = { ...buildVorgang(objectIds[1], 'DoRevokeAbschliessen'), status: VorgangStatusE2E.BESCHIEDEN };

	before(() => {
		initVorgaenge([vorgangAbschliessen, vorgangAbschliessenRevoke]);

		loginAsSabine();

		waitForSpinnerToDisappear();
		exist(vorgangList.getRoot());
	})

	after(() => {
		dropCollections();
	})

	describe('abschliessen', () => {

		it('Open Vorgang-Detail-Page', () => {
			vorgangList.getListItem(vorgangAbschliessen.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangPage.getVorgangDetailHeader().getRoot());
		})

		describe('by button', () => {

			it('should have status Beschieden', () => {
				haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangAbschliessen.status]);
			})

			it('should show snackBar message', () => {
				vorgangFormularButtons.getAbschliessenButton().click();
				waitForSpinnerToDisappear();

				exist(snackBar.getCloseButton());
				contains(snackBar.getMessage(), VorgangMessagesE2E.ABGESCHLOSSEN)
			})

			it('should close snackBar', () => {
				snackBar.getCloseButton().click();

				notExist(snackBar.getMessage());
			})

			it('should have status Abgeschlossen', () => {
				haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ABGESCHLOSSEN]);
			})

			it('back to vorgang list', () => {
				vorgangPage.getSubnavigation().getBackButton().click();
				waitForSpinnerToDisappear();

				exist(vorgangList.getRoot());
			})

			it('should have status Abgeschlossen', () => {
				haveText(vorgangList.getListItem(vorgangAbschliessen.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.ABGESCHLOSSEN]);
			})
		})
	})

	describe('abschliessen und rückgängig machen', () => {

		it('Open Vorgang-Detail-Page', () => {
			vorgangList.getListItem(vorgangAbschliessenRevoke.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangPage.getVorgangDetailHeader().getRoot());
		})

		describe('by icon-button', () => {

			it('should have status Beschieden', () => {
				haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[vorgangAbschliessenRevoke.status]);
			})

			it('should show snackBar message', () => {
				vorgangPage.getSubnavigation().getAbschliessenIconButton().click();
				waitForSpinnerToDisappear();

				exist(snackBar.getCloseButton());
				contains(snackBar.getMessage(), VorgangMessagesE2E.ABGESCHLOSSEN);
			})

			it('should close snackbar on revoke', () => {
				snackBar.getRevokeButton().click();
				waitForSpinnerToDisappear();

				notExist(snackBar.getMessage());
			})

			it('should show status Beschieden', () => {
				notExist(vorgangPage.getProgressBar());

				haveText(vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.BESCHIEDEN]);
			})

			it('back to vorgang list', () => {
				vorgangPage.getSubnavigation().getBackButton().click();
				waitForSpinnerToDisappear();

				exist(vorgangList.getRoot());
			})

			it('should have status Beschieden', () => {
				haveText(vorgangList.getListItem(vorgangAbschliessenRevoke.name).getStatus(), vorgangStatusLabelE2E[VorgangStatusE2E.BESCHIEDEN])
			})
		})
	})
});
