/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { formatDate, registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { ExpansionPanelE2Eomponent } from '../../../components/ui/expansion-panel.e2e.component';
import { AntragstellerE2EComponent } from '../../../components/vorgang/vorgang-antragsteller.e2e.component';
import { VorgangDetailHeaderE2EComponent } from '../../../components/vorgang/vorgang-detail-header.e2e.component';
import { VorgangFormularDatenE2EComponent } from '../../../components/vorgang/vorgang-formular.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { NO_AKTENZEICHEN, VorgangE2E, vorgangStatusLabelE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections, reload } from '../../../support/cypress-helper';
import { contains, exist, haveText, shouldFirstContains, shouldHaveAttributeBeGreaterThan, shouldHaveAttributeBeLowerThan } from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import { AntragstellerE2ETestData, buildVorgang, createVorgang, initVorgaenge, objectIds } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang Detailansicht', () => {
	const mainPage: MainPage = new MainPage();
	const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

	const vorgangPage: VorgangPage = new VorgangPage();
	const vorgangDatenFormular: VorgangFormularDatenE2EComponent = vorgangPage.getFormularDatenContainer();

	const vorgangHeader: VorgangDetailHeaderE2EComponent = vorgangPage.getVorgangDetailHeader();
	const expansionPanelContainer: ExpansionPanelE2Eomponent = vorgangPage.getFormularDatenContainer().getExpansionPanelContainer();
	const antragsteller: AntragstellerE2EComponent = vorgangPage.getAntragstellerContainer();

	const vorgang: VorgangE2E = { ...createVorgang(), name: 'TestVorgang' };
	const vorgangTwo: VorgangE2E = buildVorgang(objectIds[0], 'TestVorgangWithAntragstellerNull');
	const vorgangWithAntragstellerNull: VorgangE2E = {
		...vorgangTwo,
		eingangs: [{ ...vorgangTwo.eingangs[0], antragsteller: null }]
	};

	before(() => {
		initVorgaenge([vorgang, vorgangWithAntragstellerNull]);

		loginAsSabine();

		waitForSpinnerToDisappear();
		exist(vorgangList.getRoot());
	})

	after(() => {
		dropCollections();
	})

	describe('navigate to vorgang detail', () => {

		describe('click on vorgang in list', () => {

			it('should show header', () => {
				vorgangList.getListItem(vorgang.name).getRoot().click();
				waitForSpinnerToDisappear();

				exist(vorgangHeader.getRoot());
			})

			it('should have header data', () => {
				haveText(vorgangHeader.getStatus(), vorgangStatusLabelE2E[vorgang.status]);
				haveText(vorgangHeader.getAktenzeichen(), vorgang.aktenzeichen ? vorgang.aktenzeichen : NO_AKTENZEICHEN);
				haveText(vorgangHeader.getVorgangNummer(), vorgang.nummer);
				haveText(vorgangHeader.getName(), vorgang.name);
				haveText(vorgangHeader.getCreatedAt(), formatDate(vorgang.createdAt.$date, 'EEEE, dd. MMMM y, HH:mm', 'de'));
			})

			it('should have header data after reload', () => {
				reload();

				exist(vorgangHeader.getRoot());
				haveText(vorgangHeader.getStatus(), vorgangStatusLabelE2E[vorgang.status]);
				haveText(vorgangHeader.getAktenzeichen(), vorgang.aktenzeichen ? vorgang.aktenzeichen : NO_AKTENZEICHEN);
				haveText(vorgangHeader.getVorgangNummer(), vorgang.nummer);
				haveText(vorgangHeader.getName(), vorgang.name);
				haveText(vorgangHeader.getCreatedAt(), formatDate(vorgang.createdAt.$date, 'EEEE, dd. MMMM y, HH:mm', 'de'));
			})
		})

		// SKIP: Metada sind aktuell disabled
		describe.skip('metadaten in tab', () => {

			it('should show on click on tab', () => {
				vorgangDatenFormular.getMetadatenTab().click();

				exist(vorgangDatenFormular.getMetadaten());
			})

			it('should show "empfangendestelle"', () => {
				contains(vorgangDatenFormular.getRoot(), vorgang.eingangs[0].formData.empfangendestelle.emailadresse);
			})
		})

		describe('antragdaten in tab', () => {

			it('should show on click on tab', () => {
				vorgangDatenFormular.getAntragdatenTab().click();

				exist(vorgangDatenFormular.getAntragdaten());
			})

			it('should show "bez flurstueck"', () => {
				contains(vorgangDatenFormular.getRoot(), vorgang.eingangs[0].formData.bezFlurstuek[0]);
				contains(vorgangDatenFormular.getRoot(), vorgang.eingangs[0].formData.bezFlurstuek[1]);
			})
		})

		describe('historie in tab', () => {

			it('should show on click on tab', () => {
				vorgangDatenFormular.getHistorieTab().click();

				exist(vorgangDatenFormular.getHistorieContainer().getRoot());
			})

			it('should show vorgang created at', () => {
				exist(vorgangDatenFormular.getHistorieContainer().getCreatedAt());
			})
		})

		describe('expansion panel', () => {

			it('should contains Formulardaten panel', () => {
				shouldFirstContains(expansionPanelContainer.getExpansionPanelTitle(), 'Formulardaten');
			})

			it('should have Formulardaten panel open initial', () => {
				shouldHaveAttributeBeGreaterThan(expansionPanelContainer.getExpansionPanel(), 'outerHeight', 50);
			})

			it('should close the panel', () => {
				expansionPanelContainer.getExpansionPanelTitle().first().click();

				shouldHaveAttributeBeLowerThan(expansionPanelContainer.getExpansionPanel(), 'outerHeight', 50);
			})
		})
	})

	describe('Antragsdaten', () => {

		it('should contains Antragsteller area', () => {
			exist(antragsteller.getRoot());
		})

		it('should contains name', () => {
			exist(antragsteller.getName());
			contains(antragsteller.getName(), AntragstellerE2ETestData.anrede);
			contains(antragsteller.getName(), AntragstellerE2ETestData.vorname);
			contains(antragsteller.getName(), AntragstellerE2ETestData.nachname);
		})

		it('should contains email', () => {
			exist(antragsteller.getEmail());
			contains(antragsteller.getEmail(), AntragstellerE2ETestData.email);
		})

		it('should contains telefon', () => {
			exist(antragsteller.getTelefon());
			contains(antragsteller.getTelefon(), AntragstellerE2ETestData.telefon);
		})

		it('should contains adresse', () => {
			exist(antragsteller.getStrasseHausnummer());
			contains(antragsteller.getStrasseHausnummer(), AntragstellerE2ETestData.strasse);
			contains(antragsteller.getStrasseHausnummer(), AntragstellerE2ETestData.hausnummer);

			exist(antragsteller.getPlzOrt());
			contains(antragsteller.getPlzOrt(), AntragstellerE2ETestData.plz);
			contains(antragsteller.getPlzOrt(), AntragstellerE2ETestData.ort);
		})

		it('should contains birth data', () => {
			exist(antragsteller.getBirthData());
			contains(antragsteller.getBirthData(), AntragstellerE2ETestData.geburtsort);
		})

		it('should show vorgang header', () => {
			vorgangPage.getSubnavigation().getBackButton().click();
			waitForSpinnerToDisappear();
		})
	})

	describe('Antragsdaten null', () => {
		it('should show vorgang header', () => {
			vorgangList.getListItem(vorgangWithAntragstellerNull.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangHeader.getRoot());
		})

		it('should show noAntragsteller', () => {
			exist(antragsteller.getNoAntragsteller());
			contains(antragsteller.getNoAntragsteller(), 'Nicht vorhanden.');
		})
	})
});