/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { NgModule } from '@angular/core';
import { TestBed } from '@angular/core/testing';
import { mock } from '@alfa-client/test-utils';
import { EffectsModule } from '@ngrx/effects';
import { Store, StoreModule } from '@ngrx/store';
import { readFirst } from '@nx/angular/testing';
import { createApiRootResource } from 'libs/api-root-shared/test/api-root';
import { of } from 'rxjs';
import { ApiRootResource } from '../api-root.model';
import { ApiRootRepository } from '../api-root.repository';
import * as ApiRootActions from './api-root.actions';
import { ApiRootEffects } from './api-root.effects';
import { ApiRootFacade } from './api-root.facade';
import { ApiRootPartialState, API_ROOT_FEATURE_KEY, reducer } from './api-root.reducer';

describe('ApiRootFacade', () => {
	let facade: ApiRootFacade;
	let store: Store<ApiRootPartialState>;

	const apiRootRepository = mock(ApiRootRepository);

	describe('used in NgModule', () => {
		beforeEach(() => {
			@NgModule({
				imports: [
					StoreModule.forFeature(API_ROOT_FEATURE_KEY, reducer),
					EffectsModule.forFeature([ApiRootEffects]),
				],
				providers: [ApiRootFacade,
					{
						provide: ApiRootRepository,
						useValue: apiRootRepository
					}],
			})
			class CustomFeatureModule { }

			@NgModule({
				imports: [
					StoreModule.forRoot({}),
					EffectsModule.forRoot([]),
					CustomFeatureModule,
				],
			})
			class RootModule { }
			TestBed.configureTestingModule({ imports: [RootModule] });

			store = TestBed.inject(Store);
			facade = TestBed.inject(ApiRootFacade);
		});

		describe('get historie', () => {

			const apiRootResource: ApiRootResource = createApiRootResource();

			beforeEach(() => {
				apiRootRepository.loadApiRoot.mockReturnValue(of(apiRootResource));
			})

			it('should return loading state resource on required loading resource', async () => {
				let stateList = await readFirst(facade.getApiRoot());

				expect(stateList.resource).toBeNull();
				expect(stateList.loading).toEqual(true);
			})

			it('should return the loaded state resource', async () => {
				let stateList = await readFirst(facade.getApiRoot());
				expect(stateList.resource).toBeNull();
				expect(stateList.loading).toEqual(true);

				store.dispatch(ApiRootActions.loadApiRootSuccess({ apiRoot: apiRootResource }));

				stateList = await readFirst(facade.getApiRoot());
				expect(stateList.resource).toBe(apiRootResource);
				expect(stateList.loading).toBe(false);
			});
		})
	});
});
