/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HttpParams } from '@angular/common/http';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { ApiDownloadToken } from '@alfa-client/api-root-shared';
import { BinaryFileLinkRel, BinaryFileResource } from '@alfa-client/binary-file-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { getUrl, Resource } from '@ngxp/rest';
import { isEmpty, isNil } from 'lodash-es';

@Component({
	selector: 'alfa-binary-file',
	templateUrl: './binary-file.component.html',
	styleUrls: ['./binary-file.component.scss']
})
export class BinaryFileComponent {

	@Input() file: BinaryFileResource;
	@Input() stateResource: StateResource<Resource>;
	@Input() deletable: boolean = false;
	@Input() downloadToken: ApiDownloadToken = <ApiDownloadToken>{};

	readonly fileLinkRel = BinaryFileLinkRel;

	@Output() public startDownload: EventEmitter<BinaryFileResource> = new EventEmitter<BinaryFileResource>();
	@Output() public startDelete: EventEmitter<BinaryFileResource> = new EventEmitter<BinaryFileResource>();
	@Output() public getDownloadToken: EventEmitter<void> = new EventEmitter<void>();

	get isDisabled(): boolean {
		return this.getStateResource().loading;
	}

	getStateResource(): StateResource<Resource> {
		return isNil(this.stateResource) ? createEmptyStateResource<Resource>() : this.stateResource;
	}

	downloadFile(): void {
		this.startDownload.emit(this.file);
	}

	deleteFile(): void {
		this.startDelete.emit(this.file);
	}

	getNewDownloadToken(): void {
		this.getDownloadToken.emit();
	}

	dragStart(event: DragEvent): void {
		event.dataTransfer.setData('DownloadURL', this.createDownloadUrl());
	}

	dragEnd(event: DragEvent): void {
		if (this.isValidDrop(event)) {
			this.handleSpinnerForDragEnd();
		}
	}

	private isValidDrop(event: DragEvent): boolean {
		return event.dataTransfer.dropEffect !== 'none';
	}

	handleSpinnerForDragEnd(): void {
		this.stateResource = { ...this.stateResource, loading: true };
		setTimeout(() => this.stateResource = { ...this.stateResource, loading: false }, 3000);
	}

	createDownloadUrl(): string {
		return `${this.getContentType()}:${this.file.name}:${this.createRemoteUrl()}`;
	}

	private getContentType(): string {
		return isEmpty(this.file.contentType) ? 'application/octet-stream' : this.file.contentType;
	}

	private createRemoteUrl(): string {
		let getParam = new HttpParams();
		getParam = getParam.set('token', this.downloadToken?.token);

		return getUrl(this.file, BinaryFileLinkRel.DOWNLOAD) + '?' + getParam.toString();
	}

}
