import { StateResource, createEmptyStateResource } from '@alfa-client/tech-shared';
import { createCreateCommand } from 'libs/command-shared/test/command';
import { CommandOrder, CommandResource, CreateCommand } from '../command.model';
import { CommandPartialState, initialState } from './command.reducer';

import * as Selectors from './command.selectors';

describe('Command Selectors', () => {

	let state: CommandPartialState;

	const commandInState: CreateCommand = createCreateCommand();
	const commandInStateOrder: CommandOrder = CommandOrder.VORGANG_ANNEHMEN;
	const commandByOrderMap: any = { [commandInStateOrder]: commandInState };

	beforeEach(() => {
		state = {
			CommandState: {
				...initialState,
				commandByOrderMap
			}
		};
	});

	describe('commandByOrderMap', () => {

		it('should select commandByOrderMap', () => {
			const result: any = Selectors.commandByOrderMap.projector(state.CommandState);

			expect(result).toBe(commandByOrderMap);
		})
	})

	describe('commandByOrder', () => {

		it('should return command from map by order', () => {
			const result: StateResource<CommandResource> = Selectors.commandByOrder(commandInStateOrder).projector(commandByOrderMap);

			expect(result).toBe(commandInState);
		})

		it('should return empty state resource on empty object', () => {
			const result: StateResource<CommandResource> = Selectors.commandByOrder(commandInStateOrder).projector({});

			expect(result).toEqual(createEmptyStateResource());
		})
	})
});