import { ComponentFixture, TestBed } from '@angular/core/testing';
import { HintService } from '@alfa-client/hint-shared';
import { Mock, existsAsHtmlElement, mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { HintContainerComponent } from './hint-container.component';
import { UserNoOrganisationsEinheitIdHintComponent } from './user-no-organisations-einheit-id-hint/user-no-organisations-einheit-id-hint.component';

describe('HintContainerComponent', () => {
	let component: HintContainerComponent;
	let fixture: ComponentFixture<HintContainerComponent>;

	const noOrganisationsEinheitIdHint: string = getDataTestIdOf('no-organisations-einheit-id-hint');
	const service: Mock<HintService> = mock(HintService);

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				HintContainerComponent,
				MockComponent(UserNoOrganisationsEinheitIdHintComponent)
			],
			providers: [
				{
					provide: HintService,
					useValue: service
				}
			]
		}).compileComponents();

		fixture = TestBed.createComponent(HintContainerComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ngOnInit', () => {

		it('should call service to get hasUserNoOrganisationsEinheitIdHint', () => {
			component.ngOnInit();

			expect(service.hasUserNoOrganisationsEinheitIdHint).toHaveBeenCalled();
		})
	})

	describe('no organisationsEinehit id', () => {

		it('should hide if hint resource is null', () => {
			component.hasUserNoOrganisationsEinheitIdHint$ = of(false);

			fixture.detectChanges();

			notExistsAsHtmlElement(fixture, noOrganisationsEinheitIdHint);
		})

		it('should show if hint resource exists', () => {
			component.hasUserNoOrganisationsEinheitIdHint$ = of(true);

			fixture.detectChanges();

			existsAsHtmlElement(fixture, noOrganisationsEinheitIdHint);
		})
	})
});
