/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, Input, OnChanges } from '@angular/core';
import { KommentarListResource, KommentarService } from '@alfa-client/kommentar-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { mergeMap, Observable } from 'rxjs';

@Component({
	selector: 'alfa-kommentar-list-in-vorgang-container',
	templateUrl: './kommentar-list-in-vorgang-container.component.html',
	styleUrls: ['./kommentar-list-in-vorgang-container.component.scss']
})
export class KommentarListInVorgangContainerComponent implements OnChanges {

	@Input() vorgangStateResource: StateResource<VorgangWithEingangResource>;

	showFormular$: Observable<boolean>;
	kommentarListStateResource$: Observable<StateResource<KommentarListResource>>;
	canCreateNewKommentar$: Observable<boolean>;

	constructor(private kommentarService: KommentarService) {
	}

	ngOnChanges(): void {
		this.reloadKommentarListOnVorgangReload();
		this.showFormular$ = this.kommentarService.isFormularVisible();
		this.kommentarListStateResource$ = this.kommentarService.getKommentareByVorgang(this.vorgangStateResource.resource);
		this.canCreateNewKommentar$ = this.kommentarListStateResource$.pipe(
			mergeMap(stateResource => this.kommentarService.canCreateNewKommentar(stateResource.resource)));
	}

	reloadKommentarListOnVorgangReload(): void {
		if (this.vorgangStateResource.reload) {
			this.kommentarService.setKommentarListReload();
		}
	}

	showFormular(): void {
		this.kommentarService.showFormular();
	}

	hideFormular(): void {
		this.kommentarService.hideFormular();
	}
}