/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { PostfachService } from '@alfa-client/postfach-shared';
import { createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { DialogService, FileUploadComponent, IconButtonWithSpinnerComponent, OzgcloudStrokedButtonWithSpinnerComponent, SpinnerComponent, TextAreaEditorComponent, TextEditorComponent } from '@alfa-client/ui';
import { createCommandResource } from 'libs/command-shared/test/command';
import { PostfachTestFactory } from 'libs/postfach-shared/test/postfach';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { PostfachMailFormComponent } from './postfach-mail-form.component';
import { PostfachMailFormservice } from './postfach-mail.formservice';
import { PostfachNachrichtAttachmentContainerComponent } from './postfach-nachricht-attachment-container/postfach-nachricht-attachment-container.component';
import { PostfachNachrichtReplyEditorContainerComponent } from './postfach-nachricht-reply-editor-container/postfach-nachricht-reply-editor-container.component';

import * as CommandUtil from '../../../../command-shared/src/lib/command.util';

describe('PostfachMailFormComponent', () => {
	let component: PostfachMailFormComponent;
	let fixture: ComponentFixture<PostfachMailFormComponent>;

	const postfachService: Mock<PostfachService> = mock(PostfachService);
	const formService: PostfachMailFormservice = new PostfachMailFormservice(new FormBuilder(), useFromMock(postfachService));
	const dialogService: Mock<DialogService> = mock(DialogService);

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				PostfachMailFormComponent,
				MockComponent(TextAreaEditorComponent),
				MockComponent(TextEditorComponent),
				MockComponent(IconButtonWithSpinnerComponent),
				MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
				MockComponent(PostfachNachrichtReplyEditorContainerComponent),
				MockComponent(SpinnerComponent),
				MockComponent(FileUploadComponent),
				MockComponent(PostfachNachrichtAttachmentContainerComponent)
			],
			imports: [
				MatFormFieldModule,
				MatInputModule,
				ReactiveFormsModule,
				BrowserAnimationsModule
			],
			providers: [
				{
					provide: PostfachMailFormservice,
					useValue: formService
				},
				{
					provide: PostfachService,
					useValue: postfachService
				},
				{
					provide: DialogService,
					useValue: dialogService
				},
				{
					provide: MAT_DIALOG_DATA,
					useValue: { ...PostfachTestFactory.POSTFACH_MAIL_FORM_DIALOG_DATA, postfachNachricht: undefined }
				}
			]
		}).compileComponents();
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(PostfachMailFormComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ngOnInit', () => {

		describe('on existing postfachNachricht', () => {

			beforeEach(() => {
				component.dialogData = PostfachTestFactory.POSTFACH_MAIL_FORM_DIALOG_DATA;
				component.patchPostfachNachricht = jest.fn();
			})

			it('should patch', () => {
				component.ngOnInit();

				expect(component.patchPostfachNachricht).toHaveBeenCalled();
			})
		})
	})

	describe('patchPostfachNachricht', () => {

		it.skip('should do patch', () => {
			component.patchPostfachNachricht();

			expect(formService.patch).toHaveBeenCalled();
		})
	})

	describe('submit', () => {

		beforeEach(() => {
			postfachService.sendMail.mockReturnValue(of(createStateResource(createCommandResource())));
		})

		it.skip('should submit on form', () => {
			formService.submit = jest.fn();

			component.submit();

			expect(formService.submit).toHaveBeenCalled();
		})

		it.skip('should close dialog', () => {
			component.closeDialogsOnSuccessfulSubmit = jest.fn();

			component.sendInProgress$.subscribe();
			component.submit();

			expect(component.closeDialogsOnSuccessfulSubmit).toHaveBeenCalled();
		})
	})

	describe('closeDialogsOnSuccessfulSubmit', () => {

		it('should close dialogs on successful done', () => {
			jest.spyOn(CommandUtil, 'isSuccessfulDone').mockReturnValue(true);

			component.closeDialogsOnSuccessfulSubmit(createStateResource(createCommandResource()));

			expect(dialogService.closeAll).toHaveBeenCalled();
		})

		it('should not close dialogs on NOT successful done', () => {
			dialogService.closeAll.mockClear();
			jest.spyOn(CommandUtil, 'isSuccessfulDone').mockReturnValue(false);

			component.closeDialogsOnSuccessfulSubmit(createStateResource(createCommandResource()));

			expect(dialogService.closeAll).not.toHaveBeenCalled();
		})
	})
});