/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { FileSizePipe } from './file-size.pipe';

describe('FileSizePipe', () => {
	const pipe = new FileSizePipe();

	it('create an instance', () => {
		expect(pipe).toBeTruthy();
	});

	describe('pass date in pipe', () => {
		const kb = 1024;

		it('1.073.741.824 should return 1,00 GB', () => {
			const size = Math.pow(kb, 3);

			const pipeResult: string = pipe.transform(size);

			expect(pipeResult).toBe('1,00<span class="unit">GB</span>');
		});

		it('1.048.576 should return 1,00 MB', () => {
			const size = Math.pow(kb, 2);

			const pipeResult: string = pipe.transform(size);

			expect(pipeResult).toBe('1,00<span class="unit">MB</span>');
		});

		it('1000 should return 0,98 kB', () => {
			const size = 1000;
			const expectedSize = (size / kb).toFixed(2).replace('.', ',');

			const pipeResult: string = pipe.transform(size);

			expect(pipeResult).toBe(`${expectedSize}<span class="unit">kB</span>`);
		});
	});


});
