/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { MatIconRegistry } from '@angular/material/icon';
import { IconService } from './icon.service';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { Icons } from './icon.model';

describe('IconService', () => {
	let service: IconService;
	let matIconRegistry: Mock<MatIconRegistry>;
	let domSanitizer: Mock<any>;

	const iconBasePath: string = '/assets/icons/';
	const iconsObjectLength = Object.keys(Icons).length

	beforeEach(() => {
		matIconRegistry = mock(MatIconRegistry);
		domSanitizer = { bypassSecurityTrustResourceUrl: jest.fn() };

		service = new IconService(useFromMock(matIconRegistry), useFromMock(domSanitizer));
	})

	it('should create', () => {
		expect(service).toBeDefined();
	})

	describe('add Icon to registry', () => {
		it('should call registry to add SvgIgon', () => {
			service.registerIcons();

			expect(matIconRegistry.addSvgIcon).toHaveBeenCalled();
			expect(matIconRegistry.addSvgIcon).toHaveBeenCalledTimes(iconsObjectLength);
		})

		it('should call domSanitizer', () => {
			service.registerIcons();

			expect(domSanitizer.bypassSecurityTrustResourceUrl).toHaveBeenCalled();
			expect(domSanitizer.bypassSecurityTrustResourceUrl).toHaveBeenCalledTimes(iconsObjectLength);
		})

		it('should call domSanitizer for `incoming` icon', () => {
			service.registerIcons();

			expect(domSanitizer.bypassSecurityTrustResourceUrl).toHaveBeenCalledWith(iconBasePath + 'incoming.svg');
		})
	})
})
