import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { MockComponent, MockDirective } from 'ng-mocks';
import { MatTooltipDirective } from '@alfa-client/ui';
import { OzgcloudIconButtonPrimaryComponent } from './ozgcloud-icon-button-primary.component';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { MatIconTestingModule } from '@angular/material/icon/testing';
import { createAriaLabelForIconButton } from '@alfa-client/tech-shared';

jest.mock('@alfa-client/tech-shared');
const createAriaLabelForIconButtonMock = createAriaLabelForIconButton as jest.Mock;

describe('IconButtonPrimaryWithSpinnerComponent', () => {
	let component: OzgcloudIconButtonPrimaryComponent;
	let fixture: ComponentFixture<OzgcloudIconButtonPrimaryComponent>;

	beforeEach(() => {
		TestBed.configureTestingModule({
			imports: [MatIconTestingModule],
			declarations: [
				OzgcloudIconButtonPrimaryComponent,
				MockComponent(MatIcon),
				MockDirective(MatTooltipDirective)
			],
		})
	})

	beforeEach(() => {
		fixture = TestBed.createComponent(OzgcloudIconButtonPrimaryComponent);
		component = fixture.componentInstance;
		component.svgIcon = 'edit';

		fixture.detectChanges();
	})

	it('should create', () => {
		expect(component).toBeTruthy();
	})

	describe('ngOnInit', () => {

		it('should create aria label', () => {
			component.ngOnInit();

			expect(createAriaLabelForIconButtonMock).toHaveBeenCalledWith(component.tooltip, component.svgIcon);
		})

		it('should set aria label', () => {
			const ariaLabel = 'Eine Taste';
			createAriaLabelForIconButtonMock.mockReturnValue(ariaLabel);

			component.ngOnInit();

			expect(component.ariaLabel).toBe(ariaLabel);
		})

	})

	describe('onClick', () => {

		it('should emit event', () => {
			const element = getElementFromFixture(fixture, getDataTestClassOf('icon-button-primary'));
			const emitSpy = jest.spyOn(component.clickEmitter, 'emit');

			element.click();

			expect(emitSpy).toHaveBeenCalled();
		})

	})

});
