import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { OzgcloudPasteTextButtonComponent } from './ozgcloud-paste-text-button.component';
import { MatTooltipDirective } from '../mattooltip/mattooltip.directive';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { isClipboardReadSupported } from '@alfa-client/tech-shared';
import { getElementFromFixture, mock } from '@alfa-client/test-utils';
import { MatIconTestingModule } from '@angular/material/icon/testing';
import { EventEmitter } from '@angular/core';
import { MockComponent, MockDirective } from 'ng-mocks';
import { OzgcloudIconButtonPrimaryComponent } from '@alfa-client/ui';

jest.mock('@alfa-client/tech-shared');
const isClipboardReadSupportedMock = isClipboardReadSupported as jest.Mock;

const clipboardContent = '1234';
const readTextMock = jest.fn().mockResolvedValue(clipboardContent);
Object.assign(navigator, { clipboard: { readText: readTextMock } });

describe('OzgcloudPasteTextButtonComponent', () => {
	let component: OzgcloudPasteTextButtonComponent;
	let fixture: ComponentFixture<OzgcloudPasteTextButtonComponent>;

	function getMatIconElement(): HTMLElement {
		return getElementFromFixture(fixture, getDataTestIdOf('paste_from_clipboard'));
	}

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			imports: [MatIconTestingModule],
			declarations: [
				OzgcloudPasteTextButtonComponent,
				MockComponent(MatIcon),
				MockComponent(OzgcloudIconButtonPrimaryComponent),
				MockDirective(MatTooltipDirective),
			]
		}).compileComponents();

		fixture = TestBed.createComponent(OzgcloudPasteTextButtonComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
		component.pasteEmitter = <any>mock(EventEmitter);
	})

	it('should create', () => {
		expect(component).toBeTruthy();
	})

	it('should have no paste supported by default', () => {
		expect(component.isPasteSupported).toBeFalsy();
	})

	it('should not render if paste not supported', () => {
		const matIcon = getMatIconElement();

		expect(matIcon).not.toBeInstanceOf(HTMLElement);
	})

	describe('ngOnInit', () => {

		it('should check if clipboard read is supported', () => {
			component.ngOnInit();

			expect(isClipboardReadSupported).toHaveBeenCalled();
		})

		it('should set paste support', () => {
			isClipboardReadSupportedMock.mockReturnValue(true);

			component.ngOnInit();

			expect(component.isPasteSupported).toBeTruthy();
		})

		it('should render if paste supported', () => {
			isClipboardReadSupportedMock.mockReturnValue(true);
			fixture.detectChanges();
			const matIcon = getMatIconElement();

			component.ngOnInit();

			expect(matIcon).toBeInstanceOf(HTMLElement);
		})
	})

	describe('onPaste', () => {

		it('should emit clipboard content', async () => {
			await component.onPaste();

			expect(component.pasteEmitter.emit).toHaveBeenCalledWith(clipboardContent);
		})

	})
})
