/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { MatSpinner } from '@angular/material/progress-spinner';
import { createEmptyStateResource } from '@alfa-client/tech-shared';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { SpinnerComponent } from './spinner.component';

describe('SpinnerComponent', () => {
	let component: SpinnerComponent;
	let fixture: ComponentFixture<SpinnerComponent>;

	const spinnerSelector: string = getDataTestClassOf('spinner');

	beforeEach(async () => {
		TestBed.configureTestingModule({
			declarations: [
				SpinnerComponent,
				MatIcon,
				MatSpinner
			]
		})
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(SpinnerComponent);
		component = fixture.componentInstance;

		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('spinner', () => {

		it('should NOT be visible if NOT loading and already loaded', () => {
			component.stateResource = { ...createEmptyStateResource(false), loaded: true };
			fixture.detectChanges();

			const spinner = getElementFromFixture(fixture, spinnerSelector);

			expect(spinner).not.toBeInstanceOf(HTMLElement);
		})

		it('should be visible if loading', () => {
			component.stateResource = createEmptyStateResource(true);
			fixture.detectChanges();

			const spinner = getElementFromFixture(fixture, spinnerSelector);

			expect(spinner).toBeInstanceOf(HTMLElement);
		});
	});

	describe('loaded spinner', () => {

		beforeEach(() => {
			component.show = false;
			fixture.detectChanges();
		})

		it('should NOT be visible if showIf return false', () => {
			const spinner = getElementFromFixture(fixture, spinnerSelector);

			expect(spinner).not.toBeInstanceOf(HTMLElement);
		})

		it('should be visible if loaded', () => {
			component.show = true;
			fixture.detectChanges();

			const spinner = getElementFromFixture(fixture, spinnerSelector);

			expect(spinner).toBeInstanceOf(HTMLElement);
		});
	});
});
