/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { mock } from '@alfa-client/test-utils';
import { OzgcloudMenuComponent, UiModule } from '@alfa-client/ui';
import { UserProfileService } from '@alfa-client/user-profile-shared';
import { MockComponent } from 'ng-mocks';
import { BehaviorSubject } from 'rxjs';
import { UserIconComponent } from '../../../user-icon/user-icon.component';
import { UserProfileSearchContainerComponent } from '../../../user-profile-search-container/user-profile-search-container.component';
import { UserProfileButtonContainerComponent } from './user-profile-button-container.component';

describe('UserProfileButtonContainerComponent', () => {
	let component: UserProfileButtonContainerComponent;
	let fixture: ComponentFixture<UserProfileButtonContainerComponent>;

	const userProfileSearchVisbilitySubj: BehaviorSubject<boolean> = new BehaviorSubject(false);
	const userProfileService = { ...mock(UserProfileService), getUserProfileSearchVisibility: () => userProfileSearchVisbilitySubj};

	beforeEach(async () => {
		TestBed.configureTestingModule({
			declarations: [
				UserProfileButtonContainerComponent,
				MockComponent(UserIconComponent),
				MockComponent(UserProfileSearchContainerComponent),
				MockComponent(OzgcloudMenuComponent)
			],
			providers: [
				{
					provide: UserProfileService,
					useValue: userProfileService
				}
			],
			imports:[
				UiModule
			]
		})
	})

	beforeEach(() => {
		fixture = TestBed.createComponent(UserProfileButtonContainerComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ngOnInit', () => {

		it('should call getUserProfileSearchVisibility', () => {
			component.getUserProfileSearchVisibility = jest.fn();

			component.ngOnInit();

			expect(component.getUserProfileSearchVisibility).toHaveBeenCalled();
		})
	})

	describe('getUserProfileSearchVisibility', () => {

		it('should call handleVisibilityChange', () => {
			component.handleVisibilityChange = jest.fn();

			component.getUserProfileSearchVisibility().subscribe();

			expect(component.handleVisibilityChange).toHaveBeenCalled();
		})
	})

	describe('handleVisibilityChange', () => {

		it('should openMenu if changed to true', () => {
			component.menuTrigger.openMenu = jest.fn();

			component.handleVisibilityChange(true);

			expect(component.menuTrigger.openMenu).toHaveBeenCalled();
		})
	})

	describe('showUserProfileSearch', () => {

		it('should call userProfileService.showUserProfileSearch', () => {
			component.showUserProfileSearch();

			expect(userProfileService.showUserProfileSearch).toHaveBeenCalled();
		})
	})

	describe('hideUserProfileSearch', () => {

		it('should call userProfileService.hideUserProfileSearch', () => {
			component.hideUserProfileSearch();

			expect(userProfileService.hideUserProfileSearch).toHaveBeenCalled();
		})
	})
});
