/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiError, createStateResource } from '@alfa-client/tech-shared';
import { Action } from '@ngrx/store';
import { createUserProfileResource } from 'libs/user-profile-shared/test/user-profile';
import { createUserSettings, createUserSettingsResource } from 'libs/user-settings-shared/test/user-settings';
import { createApiError } from '../../../../tech-shared/test/error';
import { UserSettingsResource } from '../user-settings.model';
import * as UserSettingsActions from './user-settings.actions';
import { initialUserSettingsState, userSettingsReducer, UserSettingsState } from './user-settings.reducer';

describe('User Settings Reducer', () => {

	describe('unknown action', () => {

		it('should return current state', () => {
			const action: Action = {} as Action;

			const result = userSettingsReducer(initialUserSettingsState, action);

			expect(result).toBe(initialUserSettingsState);
		})
	})

	describe('loadUserSettings', () => {
		describe('on "loadUserSettings" action', () => {
			it('should set loading to true', () => {
				const action: Action = UserSettingsActions.loadUserSettings({ currentUser: createUserProfileResource() });

				const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

				expect(state.userSettings.loading).toBeTruthy();
			})
		})
	})

	describe('on "loadUserSettingsSuccess"', () => {
		const userSettings: UserSettingsResource = createUserSettingsResource();
		const action: Action = UserSettingsActions.loadUserSettingsSuccess({ userSettings });

		it('should set loaded resource', () => {
			const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

			expect(state.userSettings).toEqual(createStateResource(userSettings));
		})

		it('should has property "notificationsSendFor"', () => {
			const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

			expect(state.userSettings).toHaveProperty('resource.notificationsSendFor');
		})
	})

	describe('on "loadUserSettingsFailure"', () => {
		it('should set apiError', () => {
			const apiError: ApiError = createApiError();
			const action: Action = UserSettingsActions.loadUserSettingsFailure({ apiError });

			const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

			expect(state.userSettings.error).toStrictEqual(apiError);
		})
	})

	describe('setUserSettings', () => {

		describe('on "setUserSettings" action', () => {

			it('should set state resource to loading', () => {
				const action: Action = UserSettingsActions.setUserSettings({ userSettings: createUserSettings() });

				const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

				expect(state.userSettings.loading).toBeTruthy();
			})
		})

		describe('on "setUserSettingsSuccess" action', () => {

			const userSettingsResource: UserSettingsResource = createUserSettingsResource();
			const action: Action = UserSettingsActions.setUserSettingsSuccess({ userSettings: userSettingsResource });

			it('should set loaded resource', () => {
				const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

				expect(state.userSettings).toEqual(createStateResource(userSettingsResource));
			})
		})

		describe('on "setUserSettingsFailure" action', () => {

			it('should set API Error', () => {
				const apiError: ApiError = createApiError();
				const action: Action = UserSettingsActions.setUserSettingsFailure({ apiError });

				const state: UserSettingsState = userSettingsReducer(initialUserSettingsState, action);

				expect(state.userSettings.error).toStrictEqual(apiError);
			})
		})
	})
})