/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { AktenzeichenEditableComponent } from '@alfa-client/vorgang-detail';
import { DialogService } from '@alfa-client/ui';
import { mock } from '@alfa-client/test-utils';
import { MockComponent } from 'ng-mocks';
import { OzgcloudIconButtonPrimaryComponent } from '@alfa-client/ui';
import { AktenzeichenComponent } from '@alfa-client/vorgang-shared-ui';
import { AktenzeichenEditDialogComponent } from '@alfa-client/vorgang-detail';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { createEmptyStateResource, HasLinkPipe } from '@alfa-client/tech-shared';
import { VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';

describe('AktenzeichenComponent', () => {
	let component: AktenzeichenEditableComponent;
	let fixture: ComponentFixture<AktenzeichenEditableComponent>;

	const dialogService = mock(DialogService);

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				HasLinkPipe,
				AktenzeichenEditableComponent,
				MockComponent(OzgcloudIconButtonPrimaryComponent),
				MockComponent(AktenzeichenComponent),
			],
			providers: [
				{
					provide: DialogService,
					useValue: dialogService
				}
			]
		}).compileComponents();
	})

	beforeEach(() => {
		fixture = TestBed.createComponent(AktenzeichenEditableComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	})

	it('should create', () => {
		expect(component).toBeTruthy();
	})

	describe('onEdit', () => {

		it('should open dialog', () => {
			const vorgang = createVorgangWithEingangResource();
			component.vorgang = vorgang;

			component.onEdit();

			expect(dialogService.openWidely).toHaveBeenCalledWith(AktenzeichenEditDialogComponent, { data: { vorgang: vorgang, } });

		})
	})

	describe('after render', () => {
		it('should render edit button', () => {
			const editIcon = fixture.nativeElement.querySelector('ozgcloud-icon-button-primary');

			fixture.detectChanges();

			expect(editIcon).not.toBeInstanceOf(HTMLElement);
		})

		it('should render edit button', () => {
			const vorgang = createVorgangWithEingangResource();
			vorgang._links[VorgangWithEingangLinkRel.SET_AKTENZEICHEN] = { href: 'http' }
			component.vorgang = vorgang;

			fixture.detectChanges();

			const editIcon = fixture.nativeElement.querySelector('ozgcloud-icon-button-primary');
			expect(editIcon).toBeInstanceOf(HTMLElement);
		})
	})
})
