/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { BescheidModule } from '@alfa-client/bescheid';
import { BinaryFileModule } from '@alfa-client/binary-file';
import { ForwardingModule } from '@alfa-client/forwarding';
import { HistorieModule } from '@alfa-client/historie';
import { KommentarModule } from '@alfa-client/kommentar';
import { LoeschAnforderungModule } from '@alfa-client/loesch-anforderung';
import { LoeschAnforderungSharedModule } from '@alfa-client/loesch-anforderung-shared';
import { PostfachModule } from '@alfa-client/postfach';
import { PostfachSharedModule } from '@alfa-client/postfach-shared';
import { TechSharedModule } from '@alfa-client/tech-shared';
import { UiModule } from '@alfa-client/ui';
import { UserProfileModule } from '@alfa-client/user-profile';
import { UserProfileSharedModule } from '@alfa-client/user-profile-shared';
import { VorgangSharedModule } from '@alfa-client/vorgang-shared';
import { VorgangSharedUiModule } from '@alfa-client/vorgang-shared-ui';
import { WiedervorlageModule } from '@alfa-client/wiedervorlage';
import { AbschliessenButtonComponent } from './buttons/abschliessen-button/abschliessen-button.component';
import { AnnehmenButtonComponent } from './buttons/annehmen-button/annehmen-button.component';
import { BearbeitenButtonComponent } from './buttons/bearbeiten-button/bearbeiten-button.component';
import { BescheidenButtonComponent } from './buttons/bescheiden-button/bescheiden-button.component';
import { VerwerfenButtonComponent } from './buttons/verwerfen-button/verwerfen-button.component';
import { WiedereroeffnenButtonComponent } from './buttons/wiedereroeffnen-button/wiedereroeffnen-button.component';
import { ZurueckholenButtonComponent } from './buttons/zurueckholen-button/zurueckholen-button.component';
import { ZurueckstellenButtonComponent } from './buttons/zurueckstellen-button/zurueckstellen-button.component';
import { VorgangDetailActionButtonsComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-action-buttons/vorgang-detail-action-buttons.component';
import { VorgangDetailAntragstellerComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-antragsteller/vorgang-detail-antragsteller.component';
import { VorgangDetailAreaComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-area.component';
import { VorgangDetailFormularButtonsComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-buttons/vorgang-detail-formular-buttons.component';
import { VorgangDetailAntragDataComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-antrag-data/vorgang-detail-antrag-data.component';
import { VorgangDetailEingangHeaderComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-antrag-data/vorgang-detail-eingang-header/vorgang-detail-eingang-header.component';
import { VorgangDetailAttachmentListComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-attachment-list/vorgang-detail-attachment-list.component';
import { VorgangDetailFormDataTableComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-form-data-table/vorgang-detail-form-data-table.component';
import { VorgangDetailFormularDatenComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-formular-daten.component';
import { VorgangDetailMetaDataComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-meta-data/vorgang-detail-meta-data.component';
import { VorgangDetailRepresentationListComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-formular-daten/vorgang-detail-representation-list/vorgang-detail-representation-list.component';
import { VorgangDetailHeaderComponent } from './vorgang-detail-page/vorgang-detail-area/vorgang-detail-header/vorgang-detail-header.component';
import { VorgangDetailBackButtonContainerComponent } from './vorgang-detail-page/vorgang-detail-back-button-container/vorgang-detail-back-button-container.component';
import { VorgangDetailBackButtonComponent } from './vorgang-detail-page/vorgang-detail-back-button-container/vorgang-detail-back-button/vorgang-detail-back-button.component';
import { VorgangDetailMoreMenuComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-detail-more-menu.component';
import { VorgangExportContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-export-container/vorgang-export-container.component';
import { ProcessVorgangContainerComponent } from './vorgang-detail-page/vorgang-detail-more-menu/vorgang-process-vorgang-container/vorgang-process-vorgang-container.component';
import { VorgangDetailPageComponent } from './vorgang-detail-page/vorgang-detail-page.component';
import { AktenzeichenEditDialogComponent } from './aktenzeichen-edit-dialog/aktenzeichen-edit-dialog.component';
import { AktenzeichenEditableComponent } from './aktenzeichen-editable/aktenzeichen-editable.component';

const routes: Routes = [
	{
		path: '',
		component: VorgangDetailPageComponent,
	},
];

@NgModule({
	imports: [
		CommonModule,
		RouterModule.forChild(routes),
		VorgangSharedModule,
		UiModule,
		TechSharedModule,
		WiedervorlageModule,
		BinaryFileModule,
		ForwardingModule,
		KommentarModule,
		VorgangSharedUiModule,
		UserProfileModule,
		UserProfileSharedModule,
		PostfachSharedModule,
		PostfachModule,
		HistorieModule,
		LoeschAnforderungModule,
		LoeschAnforderungSharedModule,
		BescheidModule,
	],
	declarations: [
		VorgangDetailPageComponent,
		VorgangDetailAreaComponent,
		VorgangDetailHeaderComponent,
		VorgangDetailEingangHeaderComponent,
		VorgangDetailFormDataTableComponent,
		VorgangDetailActionButtonsComponent,
		VorgangDetailFormularButtonsComponent,
		AnnehmenButtonComponent,
		BearbeitenButtonComponent,
		VerwerfenButtonComponent,
		ZurueckholenButtonComponent,
		BescheidenButtonComponent,
		AbschliessenButtonComponent,
		ZurueckstellenButtonComponent,
		WiedereroeffnenButtonComponent,
		VorgangDetailAntragstellerComponent,
		VorgangDetailBackButtonComponent,
		VorgangDetailBackButtonContainerComponent,
		VorgangDetailFormularDatenComponent,
		VorgangDetailAntragDataComponent,
		VorgangDetailMetaDataComponent,
		VorgangDetailAttachmentListComponent,
		VorgangDetailRepresentationListComponent,
		VorgangDetailMoreMenuComponent,
		VorgangExportContainerComponent,
		ProcessVorgangContainerComponent,
		AktenzeichenEditableComponent,
		AktenzeichenEditDialogComponent,
	],
	exports: [
		VorgangDetailAntragstellerComponent,
		VorgangDetailAntragDataComponent,
		VorgangDetailMetaDataComponent,
		VorgangDetailAttachmentListComponent,
		VorgangDetailRepresentationListComponent,
	],
})
export class VorgangDetailModule {}
