/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Injectable } from '@angular/core';
import { CommandOrder, CommandResource } from '@alfa-client/command-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { Observable } from 'rxjs';
import { VorgangFacade } from './+state/vorgang.facade';
import { VorgangWithEingangResource } from './vorgang.model';
import { createAbschliessenCommand, createAnnehmenCommand, createBearbeitenCommand, createBescheidenCommand, createVerwerfenCommand, createWiedereroeffnenCommand, createZurueckholenCommand, createZurueckstellenCommand } from './vorgang.util';

@Injectable({ providedIn: 'root' })
export class VorgangCommandService {

	constructor(private facade: VorgangFacade) { }

	public getAnnehmenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_ANNEHMEN);
	}

	public annehmen(vorgang: VorgangWithEingangResource): void {
		this.facade.annehmen(vorgang, createAnnehmenCommand());
	}

	public getBearbeitenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_BEARBEITEN);
	}

	public bearbeiten(vorgang: VorgangWithEingangResource): void {
		this.facade.bearbeiten(vorgang, createBearbeitenCommand());
	}

	public getBeschiedenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_BESCHEIDEN);
	}

	public bescheiden(vorgang: VorgangWithEingangResource): void {
		this.facade.bescheiden(vorgang, createBescheidenCommand());
	}

	public getVerwerfenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_VERWERFEN);
	}

	public verwerfen(vorgang: VorgangWithEingangResource): void {
		this.facade.verwerfen(vorgang, createVerwerfenCommand());
	}

	public getWiedereroeffnenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_WIEDEREROEFFNEN);
	}

	public wiedereroeffnen(vorgang: VorgangWithEingangResource): void {
		this.facade.wiedereroeffnen(vorgang, createWiedereroeffnenCommand());
	}

	public getZurueckholenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_ZURUECKHOLEN);
	}

	public zurueckholen(vorgang: VorgangWithEingangResource): void {
		this.facade.zurueckholen(vorgang, createZurueckholenCommand());
	}

	public getZurueckstellenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_ZURUECKSTELLEN);
	}

	public zurueckstellen(vorgang: VorgangWithEingangResource): void {
		this.facade.zurueckstellen(vorgang, createZurueckstellenCommand());
	}

	public getAbschliessenCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getStatusCommand(CommandOrder.VORGANG_ABSCHLIESSEN);
	}

	public abschliessen(vorgang: VorgangWithEingangResource): void {
		this.facade.abschliessen(vorgang, createAbschliessenCommand());
	}

	public getRevokeCommand(): Observable<StateResource<CommandResource>> {
		return this.facade.getRevokeCommand();
	}
}