/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ApiRootService } from '@alfa-client/api-root-shared';
import { EMPTY_STRING } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { VorgangListService } from '@alfa-client/vorgang-shared';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { VorgangListContainerComponent } from './vorgang-list-container.component';
import { VorgangListComponent } from './vorgang-list/vorgang-list.component';

describe('VorgangListContainerComponent', () => {
	let component: VorgangListContainerComponent;
	let fixture: ComponentFixture<VorgangListContainerComponent>;

	const searchString: string = EMPTY_STRING;
	const apiRootService: Mock<ApiRootService> = mock(ApiRootService);
	const vorgangListService = { ...mock(VorgangListService), getSearchString: jest.fn().mockReturnValue(of(searchString)) };

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				VorgangListContainerComponent,
				MockComponent(VorgangListComponent)
			],
			providers: [
				{
					provide: ApiRootService,
					useValue: apiRootService
				},
				{
					provide: VorgangListService,
					useValue: vorgangListService
				}
			]
		})
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(VorgangListContainerComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ngOnInit', () => {

		it('should call apiRootService to get apiRoot', () => {
			component.ngOnInit();

			expect(apiRootService.getApiRoot).toHaveBeenCalled();
		})

		it('should call vorgang list service to get vorgaenge', () => {
			component.ngOnInit();

			expect(vorgangListService.getVorgaenge).toHaveBeenCalled();
		})

		it('should call vorgang list service to get vorgangList', () => {
			component.ngOnInit();

			expect(vorgangListService.getVorgangList).toHaveBeenCalled();
		})

		it('should call vorgang list service to get searchString', () => {
			component.ngOnInit();

			expect(vorgangListService.getSearchString).toHaveBeenCalled();
		})
	})

	describe('load next page', () => {

		it('should call facade loadNextPage', () => {
			component.loadNextPage();

			expect(vorgangListService.loadNextPage).toHaveBeenCalled();
		})
	})
});
