/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { StateResource, createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { getElementFromFixture, mock } from '@alfa-client/test-utils';
import { SpinnerComponent } from '@alfa-client/ui';
import { WiedervorlageResource, WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { cold, hot } from 'jest-marbles';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createWiedervorlageListResource, createWiedervorlageResource } from 'libs/wiedervorlage-shared/test/wiedervorlage';
import { MockComponent } from 'ng-mocks';
import { Observable, of } from 'rxjs';
import { WiedervorlagePageContainerComponent } from './wiedervorlage-page-container.component';
import { WiedervorlagePageComponent } from './wiedervorlage-page/wiedervorlage-page.component';

describe('WiedervorlagePageContainerComponent', () => {
	let component: WiedervorlagePageContainerComponent;
	let fixture: ComponentFixture<WiedervorlagePageContainerComponent>;

	const wiedervorlagePage: string = getDataTestIdOf('wiedervorlage-page');
	const wiedervorlageService = mock(WiedervorlageService);

	beforeEach(async () => {
		TestBed.configureTestingModule({
			declarations: [
				WiedervorlagePageContainerComponent,
				MockComponent(SpinnerComponent),
				MockComponent(WiedervorlagePageComponent)
			],
			providers: [
				{
					provide: WiedervorlageService,
					useValue: wiedervorlageService
				}
			]
		})
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(WiedervorlagePageContainerComponent);
		component = fixture.componentInstance;
		wiedervorlageService.isNewWiedervorlage.mockReturnValue(of(true));
		wiedervorlageService.getWiedervorlage.mockReturnValue(of(createStateResource(createWiedervorlageResource())));
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ng after content init', () => {

		it('should load wiedervorlageList', () => {
			component.ngAfterContentInit();

			expect(wiedervorlageService.getWiedervorlageList).toHaveBeenCalled();
		})

		it('should get wiedervorlage', () => {
			component.getWiedervorlage = jest.fn().mockReturnValue(of(createStateResource(createWiedervorlageResource())));

			component.ngAfterContentInit();

			expect(component.getWiedervorlage).toHaveBeenCalled();
		})
	})

	describe('getWiedervorlage', () => {

		it('should call service if not new', () => {
			const wiedervorlageStateResource: StateResource<WiedervorlageResource> = createStateResource(createWiedervorlageResource());
			wiedervorlageService.getWiedervorlage.mockReturnValue(cold('a' , { a: wiedervorlageStateResource }));
			wiedervorlageService.isNewWiedervorlage.mockReturnValue(false);

			const wiedervorlage: Observable<StateResource<WiedervorlageResource>> = component.getWiedervorlage();

			expect(wiedervorlage).toBeObservable(hot('a', { a: wiedervorlageStateResource }));
		})

		it.skip('should return empty stateResource if new', () => {
			wiedervorlageService.isNewWiedervorlage.mockReturnValue(true);

			const wiedervorlage: Observable<StateResource<WiedervorlageResource>> = component.getWiedervorlage();

			expect(wiedervorlage).toBeObservable(hot('a', { a: createEmptyStateResource() }));
		})
	})

	describe.skip('FIXME :/: wiedervoralge page', () => {

		it('should show on existing wiedervorlageList resource', () => {
			wiedervorlageService.getWiedervorlageList.mockReturnValue(of(createStateResource(createWiedervorlageListResource())));

			component.ngAfterContentInit();
			const element = getElementFromFixture(fixture, wiedervorlagePage);

			expect(element).toBeInstanceOf(HTMLElement);
		})

		it('should not show by empty wiedervorlageList resource', () => {
			wiedervorlageService.getWiedervorlageList.mockReturnValue(of(createEmptyStateResource()));

			component.ngAfterContentInit();
			const element = getElementFromFixture(fixture, wiedervorlagePage);

			expect(element).not.toBeInstanceOf(HTMLElement);
		})
	})
});