package de.ozgcloud.alfa.statistic;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.AlfaProperties;
import de.ozgcloud.alfa.common.user.CurrentUserService;
import de.ozgcloud.alfa.common.user.UserRole;
import de.ozgcloud.alfa.vorgang.Vorgang.VorgangStatus;

@Service
class StatisticService {

	// TODO sebo: dieser Code wird später gelöscht
	static final String COUNT_WIEDERVORLAGE_NEXT_FRIST_KEY = "countWiedervorlage";
	static final String COUNT_WIEDERVORLAGE_NEXT_FRIST_TEMPLATE = COUNT_WIEDERVORLAGE_NEXT_FRIST_KEY + ":ClientAttribute.%s.nextWiedervorlageFrist";
	// END: code löschen

	static final List<VorgangStatus> VORGAENGE_STATUS_COUNT_VERWALTUNG_USER = List.of(VorgangStatus.NEU, VorgangStatus.ANGENOMMEN,
			VorgangStatus.IN_BEARBEITUNG, VorgangStatus.BESCHIEDEN, VorgangStatus.ABGESCHLOSSEN, VorgangStatus.VERWORFEN, VorgangStatus.ZU_LOESCHEN);
	static final List<VorgangStatus> VORGAENGE_STATUS_COUNT_POSTSTELLE_USER = Collections.emptyList();
	static final List<VorgangStatus> VORGAENGE_STATUS_COUNT_EINHEITLICHER_ANSPRECHPARTNER = Collections.emptyList();

	@Autowired
	private StatisticRemoteService remoteService;

	@Autowired
	private CurrentUserService currentUserService;

	@Autowired
	private AlfaProperties alfaProperties;

	public Statistic getVorgaengeStatistic() {
		var response = remoteService.getVorgaengeStatistics(List.of(VorgangStatus.ZU_LOESCHEN));
		return buildGetVorgaengeStatisticResult(response);
	}

	List<VorgangStatus> getCountByVorgangStatusList() {
		if (currentUserService.hasRole(UserRole.VERWALTUNG_USER)) {
			return VORGAENGE_STATUS_COUNT_VERWALTUNG_USER;
		}
		if (currentUserService.hasRole(UserRole.VERWALTUNG_POSTSTELLE)) {
			return VORGAENGE_STATUS_COUNT_POSTSTELLE_USER;
		}
		if (currentUserService.hasRole(UserRole.EINHEITLICHER_ANSPRECHPARTNER)) {
			return VORGAENGE_STATUS_COUNT_EINHEITLICHER_ANSPRECHPARTNER;
		}
		return Collections.emptyList();
	}

	Statistic buildGetVorgaengeStatisticResult(Map<String, StatisticResult> response) {
		return Statistic.builder()
				.existsWiedervorlageOverdue(getBooleanResult(response, StatisticRemoteService.EXISTS_WIEDERVORLAGE_OVERDUE_RESULT_NAME))
				.wiedervorlagen(getIntResult(response, StatisticRemoteService.COUNT_WIEDERVORLAGE_NEXT_FRIST_RESULT_NAME))
				.byStatus(ByStatus.builder()
						.neu(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.NEU)))
						.abgeschlossen(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.ABGESCHLOSSEN)))
						.angenommen(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.ANGENOMMEN)))
						.beschieden(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.BESCHIEDEN)))
						.verworfen(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.VERWORFEN)))
						.inBearbeitung(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.IN_BEARBEITUNG)))
						.zuLoeschen(getIntResult(response, remoteService.buildCountByStatusResultName(VorgangStatus.ZU_LOESCHEN)))
						.build())
				.build();
	}

	private int getIntResult(Map<String, StatisticResult> response, String resultName) {
		return Optional.ofNullable(response.get(resultName)).map(StatisticResult::getIntValue).orElse(0);
	}

	private boolean getBooleanResult(Map<String, StatisticResult> response, String resultName) {
		return Optional.ofNullable(response.get(resultName)).map(StatisticResult::getBoolValue).orElse(false);
	}

	// TODO sebo: dieser Code wird später gelöscht
	public Statistic countVorgang() {
		var response = remoteService.countVorgang(createCountByPathList());

		return buildStatistic(response);
	}

	List<String> createCountByPathList() {
		return List.of(String.format(COUNT_WIEDERVORLAGE_NEXT_FRIST_TEMPLATE, alfaProperties.getApplicationName()));
	}

	Statistic buildStatistic(CountVorgangResponse response) {
		return Statistic.builder().byStatus(response.getByStatus()).wiedervorlagen(extractWiedervorlageCount(response)).build();
	}

	Integer extractWiedervorlageCount(CountVorgangResponse response) {
		return Optional.ofNullable(response.getPathCountResult())
				.map(pathResultEntry -> pathResultEntry.get(COUNT_WIEDERVORLAGE_NEXT_FRIST_KEY))
				.orElse(0);
	}
	// END: code löschen
}