/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.wiedervorlage;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.command.CommandController;
import de.ozgcloud.common.errorhandling.TechnicalException;

@RestController
@RequestMapping(WiedervorlageCommandController.WIEDERVORLAGE_COMMANDS)
public class WiedervorlageCommandController {

	static final String WIEDERVORLAGE_COMMANDS = "/api/wiedervorlages/{wiedervorlageId}/{wiedervorlageVersion}/commands";

	@Autowired
	private WiedervorlageService service;

	@PostMapping
	public ResponseEntity<Void> updateWiedervorlage(@RequestBody WiedervorlageCommand command, @PathVariable String wiedervorlageId,
			@PathVariable long wiedervorlageVersion) {
		var wiedervorlage = service.getById(wiedervorlageId);
		var createdCommand = createCommand(wiedervorlage, command);

		service.updateNextFrist(wiedervorlage.getVorgangId());

		return ResponseEntity.created(linkTo(CommandController.class).slash(createdCommand.getId()).toUri()).build();
	}

	Command createCommand(Wiedervorlage wiedervorlage, WiedervorlageCommand command) {
		switch (command.getOrder()) {
			case WIEDERVORLAGE_ERLEDIGEN: {
				return service.erledigen(wiedervorlage);
			}
			case WIEDERVORLAGE_WIEDEREROEFFNEN: {
				return service.wiedereroeffnen(wiedervorlage);
			}
			case EDIT_WIEDERVORLAGE: {
				return service.editWiedervorlage(updateWiedervorlageByCommand(wiedervorlage, command), wiedervorlage.getId(),
						wiedervorlage.getVersion());
			}
			default:
				throw new TechnicalException("Unsupported order " + command.getOrder());
		}
	}

	Wiedervorlage updateWiedervorlageByCommand(Wiedervorlage wiedervorlage, WiedervorlageCommand command) {
		return wiedervorlage.toBuilder()
				.clearAttachments().attachments(command.getWiedervorlage().getAttachments())
				.betreff(command.getWiedervorlage().getBetreff())
				.beschreibung(command.getWiedervorlage().getBeschreibung())
				.frist(command.getWiedervorlage().getFrist()).build();
	}

	@RestController
	@RequestMapping(WiedervorlageCommandByVorgangController.WIEDERVORLAGE_COMMANDS_BY_VORGANG)
	public static class WiedervorlageCommandByVorgangController {

		static final String WIEDERVORLAGE_COMMANDS_BY_VORGANG = "/api/vorgangs/{vorgangId}/wiedervorlageCommands";

		@Autowired
		private WiedervorlageService service;

		@PostMapping
		public ResponseEntity<Void> createWiedervorlage(@RequestBody WiedervorlageCommand command, @PathVariable String vorgangId) {
			var createdCommand = service.createWiedervorlage(command.getWiedervorlage(), vorgangId);

			service.updateNextFrist(vorgangId);

			return ResponseEntity.created(linkTo(CommandController.class).slash(createdCommand.getId()).toUri()).build();
		}
	}
}