package de.ozgcloud.alfa.aktenzeichen;

import static de.ozgcloud.alfa.common.UserProfileUrlProviderTestFactory.*;
import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.EnumSource;
import org.mockito.InjectMocks;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;
import org.springframework.hateoas.UriTemplate;

import de.ozgcloud.alfa.common.UserProfileUrlProvider;
import de.ozgcloud.alfa.common.command.CommandController;
import de.ozgcloud.alfa.vorgang.Vorgang;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import de.ozgcloud.alfa.vorgang.VorgangWithEingangTestFactory;

class AktenzeichenModelProcessorTest {

	private final UserProfileUrlProvider urlProvider = new UserProfileUrlProvider();

	@InjectMocks
	private AktenzeichenModelProcessor processor;

	@Nested
	class TestSetAktenzeichenLink {

		@DisplayName("should not add a link if Vorgang is not present")
		@Test
		void shouldDoNothing() {
			var model = processor.process(mock(EntityModel.class));

			assertThat(model.hasLinks()).isFalse();
		}

		@ParameterizedTest
		@EnumSource(names = { "ANGENOMMEN", "IN_BEARBEITUNG" }, mode = EnumSource.Mode.EXCLUDE)
		void shouldNotCreateSetAktenzeichenLink(Vorgang.VorgangStatus vorgangStatus) {
			initUserProfileUrlProvider(urlProvider);

			var model = processor.process(buildModelWithVorgangStatus(vorgangStatus));

			assertThat(model.getLink(AktenzeichenModelProcessor.REL_SET_AKTENZEICHEN)).isEmpty();
		}

		@ParameterizedTest
		@EnumSource(names = { "ANGENOMMEN", "IN_BEARBEITUNG" })
		void shouldCreateSetAktenzeichenLink(Vorgang.VorgangStatus vorgangStatus) {
			initUserProfileUrlProvider(urlProvider);

			var model = processor.process(buildModelWithVorgangStatus(vorgangStatus));

			assertThat(model.getLink(AktenzeichenModelProcessor.REL_SET_AKTENZEICHEN)).isPresent().get()
					.extracting(Link::getHref)
					.isEqualTo(UriTemplate.of(CommandController.CommandByRelationController.COMMAND_BY_RELATION_PATH)
							.expand(VorgangHeaderTestFactory.ID, VorgangHeaderTestFactory.ID, VorgangHeaderTestFactory.VERSION).toString()
					);
		}
	}

	private EntityModel<VorgangWithEingang> buildModelWithVorgangStatus(Vorgang.VorgangStatus vorgangStatus) {
		return EntityModel.of(VorgangWithEingangTestFactory.createBuilder().status(vorgangStatus).build());
	}
}
