/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.kommentar;

import java.util.Objects;

import de.ozgcloud.alfa.common.command.CommandOrder;
import de.ozgcloud.alfa.common.command.CommandTestFactory;
import de.ozgcloud.common.test.TestUtils;

public class KommentarCommandTestFactory {

	public static final String ID = CommandTestFactory.ID;
	public static final CommandOrder ORDER = CommandOrder.CREATE_KOMMENTAR;

	public static KommentarCommand create() {
		return createBuilder().build();
	}

	public static KommentarCommand.KommentarCommandBuilder createBuilder() {
		return KommentarCommand.builder()
				.id(ID)
				.order(ORDER)
				.kommentar(KommentarTestFactory.create());
	}

	public static String createValidRequestContent() {
		return createRequestContent(create());
	}

	public static String createRequestContent(KommentarCommand command) {
		return TestUtils.loadTextFile("jsonTemplates/command/createCommandWithKommentar.json.tmpl",
				command.getOrder().name(),
				addTuedelchen(command.getKommentar().getText()));
	}

	private static String addTuedelchen(String str) {
		return Objects.isNull(str) ? null : String.format("\"%s\"", str);
	}
}
