package de.ozgcloud.alfa.common;

import static java.util.Objects.*;

import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.Optional;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;

import org.springframework.stereotype.Component;

import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.extern.log4j.Log4j2;

@Component
@Log4j2
public class DateConverter {

	private static final DateTimeFormatter DATE_TIME_FORMATTER = DateTimeFormatter.ofPattern("dd.MM.yyyy", Locale.GERMAN);

	public Optional<XMLGregorianCalendar> convertGermanFormatToISO(String dateStr) {
		try {
			if (nonNull(dateStr)) {
				return Optional.of(createDatatypeFactory().newXMLGregorianCalendar(LocalDate.parse(dateStr, DATE_TIME_FORMATTER).toString()));
			}
		} catch (Exception e) {
			LOG.warn("Date '{}' cannot be converted to ISO format.", dateStr, e);
		}
		return Optional.empty();
	}

	public XMLGregorianCalendar toXmlGregorianCalendar(ZonedDateTime date) {
		try {
			if (nonNull(date)) {
				return createDatatypeFactory().newXMLGregorianCalendar(GregorianCalendar.from(date));
			}
		} catch (Exception e) {
			LOG.warn("Date '{}' cannot be converted to ISO format.", date, e);
		}
		return null;
	}

	DatatypeFactory createDatatypeFactory() {
		try {
			return DatatypeFactory.newInstance();
		} catch (DatatypeConfigurationException e) {
			throw new TechnicalException("Error creating datatype factory.", e);
		}
	}
}
