package de.ozgcloud.alfa.export;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.LinkRelation;
import org.springframework.hateoas.server.RepresentationModelProcessor;
import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.common.FeatureToggleProperties;
import de.ozgcloud.alfa.common.ModelBuilder;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;

@Component
class ExportVorgangProcessor implements RepresentationModelProcessor<EntityModel<VorgangWithEingang>> {

	static final LinkRelation REL_EXPORT = LinkRelation.of("export");

	@Autowired
	private FeatureToggleProperties featureToggleProperties;

	@Override
	public EntityModel<VorgangWithEingang> process(EntityModel<VorgangWithEingang> model) {
		var vorgang = model.getContent();

		if (Objects.isNull(vorgang)) {
			return model;
		}

		return ModelBuilder.fromModel(model)
				.ifMatch(featureToggleProperties::isVorgangExport)
				.addLink(linkTo(methodOn(ExportVorgangController.class).exportToXdomea(vorgang.getId())).withRel(REL_EXPORT))
				.buildModel();

	}
}
