package de.ozgcloud.alfa.file;

import java.io.OutputStream;
import java.util.List;
import java.util.function.Predicate;
import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileService;
import de.ozgcloud.alfa.common.binaryfile.FileId;
import de.ozgcloud.alfa.common.file.OzgFile;
import de.ozgcloud.alfa.common.file.OzgFileService;
import de.xoev.xdomea.DokumentType;

@Service
public class ExportFileService {

	private static final Predicate<OzgFile> IS_PDF_FILE = file -> MediaType.APPLICATION_PDF_VALUE.equals(file.getContentType());

	@Autowired
	private OzgFileService ozgFileService;

	@Autowired
	private BinaryFileService binaryFileService;

	@Autowired
	private DokumentTypeCreator dokumentTypeCreator;

	public List<OzgFile> getAllPdfs(String eingangId) {
		var representations = ozgFileService.getRepresentationsByEingang(eingangId);
		var attachments = ozgFileService.getAttachmentsByEingang(eingangId);
		return Stream.concat(representations, attachments).filter(IS_PDF_FILE).toList();
	}

	public Stream<DokumentType> createDokumentTypes(Stream<OzgFile> ozgFileStream, String formEngineName) {
		return dokumentTypeCreator.create(ozgFileStream, formEngineName);
	}

	public void writeOzgFile(FileId fileId, OutputStream outputStream) {
		binaryFileService.writeFileContent(fileId, outputStream);
	}

}
