package de.ozgcloud.alfa.export;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.Test;

import de.xoev.xdomea.DokumentType;
import de.xoev.xdomea.NkAbgabeType;
import de.xoev.xdomea.VorgangType;

public class AbgabeCreatorTest {

	private final AbgabeCreator abgabeCreator = AbgabeCreator.createAbgabeCreator();
	private final NkAbgabeType kopfType = new NkAbgabeType();
	private final VorgangType vorgangType = new VorgangType();
	private final List<DokumentType> dokumentTypes = List.of(new DokumentType(), new DokumentType());

	@Test
	void shouldSetKopf() {
		var abgabeType = abgabeCreator.withKopf(kopfType).create();

		assertThat(abgabeType.getKopf()).isEqualTo(kopfType);
	}

	@Test
	void shoulAddOneSchriftgutobjekt() {
		var abgabeType = abgabeCreator.withVorgang(vorgangType).create();

		assertThat(abgabeType.getSchriftgutobjekt()).size().isEqualTo(1);
	}

	@Test
	void shouldAddOnlyOneSchriftgutobjekt() {
		var abgabeType = abgabeCreator.withVorgang(vorgangType).withVorgang(vorgangType).create();

		assertThat(abgabeType.getSchriftgutobjekt()).size().isEqualTo(1);
	}

	@Test
	void shouldSetVorgang() {
		var abgabeType = abgabeCreator.withVorgang(vorgangType).create();

		assertThat(abgabeType.getSchriftgutobjekt().get(0).getVorgang()).isEqualTo(vorgangType);
	}

	@Test
	void shouldAddDokumentTypes() {
		var abgabeType = abgabeCreator.withVorgang(vorgangType).withDokumentTypes(dokumentTypes.stream()).create();

		assertThat(abgabeType.getSchriftgutobjekt().get(0).getVorgang().getDokument()).isEqualTo(dokumentTypes);
	}

	@Test
	void shouldThrowExceptionIfVorgangNotSet() {
		assertThatThrownBy(() -> abgabeCreator.withDokumentTypes(dokumentTypes.stream())).isExactlyInstanceOf(IllegalStateException.class);
	}
}
